<?php


namespace Fastrack\Gallery;


use Fastrack\Utilities\ModelUtilities;
use PlatoCreative\Imgix\Imgix;
use SilverStripe\AssetAdmin\Forms\UploadField;
use SilverStripe\ORM\DataObject;
use SilverStripe\Security\Permission;
use SilverStripe\Security\PermissionProvider;
use SilverStripe\View\ArrayData;

class Slide extends DataObject implements PermissionProvider
{

	private static $table_name = 'slide';

	private static $db = [
		'Title' => 'Varchar(255)',
		'Excerpt' => 'Text',
		'Body' => 'Text',
		'Link' => 'Varchar(255)',
		'SortOrder' => 'Int',
	];

	private static $has_one = [
		'Gallery' => Gallery::class,
		'Image' => Imgix::class,
	];

    private static $owns = [
        'Image',
    ];

	private static $default_sort = 'SortOrder';

	private static $translate = [
		'Title',
		'Excerpt',
		'Body',
	];

	public function Thumbnail()
	{
		if ($this->Image) {
			return $this->Image->Fill(100, 100);
		}
		return '';
	}

	public function getCMSFields()
	{
		$fields = parent::getCMSFields();
		$fields->removeByName('SortOrder');
		foreach ($this->hasOne() as $key => $value) {
			$fields->removeByName($key . 'ID');
		}
		ModelUtilities::hideFields($this, $fields);
		ModelUtilities::hideConfigFields(self::class, $fields);
		return $fields;
	}


	public function providePermissions()
	{
		$permisions = [
			'MANAGE_SLIDES' => [
				'name' => 'Manage slides',
				'category' => 'Gallery',
			],
		];
		$this->extend('updatePermisions', $permisions);
		return $permisions;
	}

	public function canView($member = null)
	{
		return Permission::check(['MANAGE_SLIDES']);
	}

	public function canEdit($member = null)
	{
		return Permission::check(['MANAGE_SLIDES']);
	}

	public function canDelete($member = null)
	{
		return Permission::check(['MANAGE_SLIDES']);
	}

	public function canCreate($member = null, $context = array())
	{
		return Permission::check(['MANAGE_SLIDES']);
	}

	/**
	 * Build link with label from markdown format
	 *
	 * E.g. [Link name](https://link.com)
	 *
	 * @return ArrayData|null
	 */
	public function BuildLink()
	{
		if (!$this->Link) {
			return null;
		}
		$matched = preg_match('/(\[)(.+)(\])(\()(.+)(\))/', $this->Link, $matches);
		if (!$matched) {
			return new ArrayData(['Link' => $this->Link]);
		}
		return new ArrayData([
			'Label' => $matches[2],
			'Link' => $matches[5],
		]);
	}

}
